@@ -5,19 +5,16 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-
 #include <QMenu>
 
-
 /**
  * @author Michael Jansen <kde@michael-jansen.biz>
  */
 class ConditionTypeMenu : public QMenu
-    {
+{
     Q_OBJECT
 
 public:
-
     /**
      * Default constructor
      */
@@ -28,14 +25,13 @@ public:
      */
     virtual ~ConditionTypeMenu();
 
-    enum ConditionType{
-            ACTIVE_WINDOW,
-            EXISTING_WINDOW,
-            AND,
-            OR,
-            NOT};
-
+    enum ConditionType {
+        ACTIVE_WINDOW,
+        EXISTING_WINDOW,
+        AND,
+        OR,
+        NOT,
+    };
 };
 
-
 #endif /* #ifndef CONDITION_TYPE_MENU_H */
